@@ -1,5 +1,5 @@
 /******************************************************************************
- * Copyright (C) 2011 Patrick Wacker
+ * Copyright (C) 2011-2013 Patrick Wacker
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the Free
  * Software Foundation; either version 2 of the License, or (at your option)
@@ -16,10 +16,10 @@
  ******************************************************************************
  * Dont forget: svn propset svn:keywords "Date Author Rev HeadURL" filename
  ******************************************************************************
- * $HeadURL: http://schmufu.dyndns.org/svn/ab_transfers/tags/0.0.4.1/src/abt_job_ctrl.h $
+ * $HeadURL: http://schmufu.dyndns.org/svn/ab_transfers/tags/0.0.5.0/src/abt_job_ctrl.h $
  * $Author: Patrick Wacker $
- * $Date: 2012-09-07 01:14:52 +0200 (Fri, 07 Sep 2012) $
- * $Rev: 351 $
+ * $Date: 2013-09-05 16:50:02 +0200 (Thu, 05 Sep 2013) $
+ * $Rev: 591 $
  *
  * description:
  *
@@ -116,6 +116,8 @@ private:
 					     int lastPos) const;
 	int getSupposedJobqueuePos(const abt_jobInfo *job) const;
 
+	bool exportImExporterContext(AB_IMEXPORTER_CONTEXT *ctx) const;
+
 public:
 	explicit abt_job_ctrl(aqb_Accounts *allAccounts, abt_history *history,
 			      QObject *parent = 0);
@@ -134,6 +136,11 @@ signals:
 	void jobQueueListChanged();
 	void jobAdded(const abt_jobInfo *jobInfo);
 	void log(const QString &str);
+	/** \brief is emitted when all jobs are executed.
+	 *
+	 * \a successfull is true when everything went fine, otherwise false.
+	 */
+	void executionFinished(bool successfull);
 
 public slots:
 	void addNewSingleTransfer(const aqb_AccountInfo *acc, const abt_transaction *t);
