@@ -1,5 +1,5 @@
 /******************************************************************************
- * Copyright (C) 2011 Patrick Wacker
+ * Copyright (C) 2011-2013 Patrick Wacker
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the Free
  * Software Foundation; either version 2 of the License, or (at your option)
@@ -16,10 +16,10 @@
  ******************************************************************************
  * Dont forget: svn propset svn:keywords "Date Author Rev HeadURL" filename
  ******************************************************************************
- * $HeadURL: http://schmufu.dyndns.org/svn/ab_transfers/tags/0.0.4.1/src/abt_settings.cpp $
+ * $HeadURL: http://schmufu.dyndns.org/svn/ab_transfers/tags/0.0.5.0/src/abt_settings.cpp $
  * $Author: Patrick Wacker $
- * $Date: 2013-02-26 21:28:42 +0100 (Tue, 26 Feb 2013) $
- * $Rev: 359 $
+ * $Date: 2013-09-05 14:15:09 +0200 (Thu, 05 Sep 2013) $
+ * $Rev: 587 $
  *
  * description:
  *
@@ -92,6 +92,11 @@ abt_settings::abt_settings(QObject *parent) :
 	this->m_historyFilename =
 		this->settings->value("Main/HistoryFilename", defValue).toString();
 
+	//filename for the automatic export
+	defValue = homePath + "/.abtransfers/automatic_export.csv";
+	defValue = QDir::toNativeSeparators(defValue);
+	this->m_autoExportFilename =
+		this->settings->value("Main/AutoExportFilename", defValue).toString();
 
 	this->m_textKeyDescr = NULL;
 	this->loadTextKeyDescriptions();
@@ -307,6 +312,15 @@ void abt_settings::deleteKnownRecipient(abt_EmpfaengerInfo* recipientInfo)
 	emit this->recipientsListChanged();
 }
 
+//public slot
+/** \brief stores the language wanted by the user at the settings
+ *
+ * Therefore the selected language can be restored at next start.
+ */
+void abt_settings::setLanguage(const QString &language)
+{
+	this->settings->setValue("Options/Language", language);
+}
 
 
 
@@ -385,6 +399,54 @@ void abt_settings::setAutoAddNewRecipients(bool value)
 	this->settings->setValue("Options/autoAddNewRecipients", value);
 }
 
+//public
+bool abt_settings::autoExportEnabled() const
+{
+	return this->settings->value("Options/autoExportEnabled", false).toBool();
+}
+
+//public
+void abt_settings::setAutoExportEnabled(bool value)
+{
+	this->settings->setValue("Options/autoExportEnabled", value);
+}
+
+//public
+const QString abt_settings::autoExportProfileName() const
+{
+	return this->settings->value("Options/autoExportProfileName", "csv").toString();
+}
+
+//public
+void abt_settings::setAutoExportProfileName(const QString name) const
+{
+	this->settings->setValue("Options/autoExportProfileName", name);
+}
+
+//public
+const QString abt_settings::autoExportPluginName() const
+{
+	return this->settings->value("Options/autoExportPluginName", "default").toString();
+}
+
+//public
+void abt_settings::setAutoExportPluginName(const QString name) const
+{
+	this->settings->setValue("Options/autoExportPluginName", name);
+}
+
+//public
+bool abt_settings::autoExportAsTransaction() const
+{
+	return this->settings->value("Main/AutoExportAsTransaction", true).toBool();
+}
+
+//public
+void abt_settings::setAutoExportAsTransaction(bool value)
+{
+	this->settings->setValue("Main/AutoExportAsTransaction", value);
+}
+
 /**
  * @brief reads all entrys for Im-/Exporter favorites from the settings
  *
@@ -456,6 +518,14 @@ void abt_settings::deleteAdvancedOption(const QString &option)
 	this->settings->endGroup();
 }
 
+//public
+/** \brief returns the language set by the user (or an empty string if nothing set)
+ */
+QString abt_settings::language() const
+{
+	return this->settings->value("Options/Language", QString("")).toString();
+}
+
 
 void abt_settings::saveColWidth(const QString &name, int col, int width)
 {
@@ -589,3 +659,16 @@ void abt_settings::setDataDir(const QString &dirname)
 	this->m_dataDir = dirname;
 }
 
+//public
+void abt_settings::setAutoExportFilename(const QString &filename)
+{
+	if (filename.isEmpty()) {
+		qWarning() << Q_FUNC_INFO << "filename is empty, nothing to store";
+		return; // cancel
+	}
+
+	this->settings->setValue("Main/AutoExportFilename", filename);
+
+	this->m_autoExportFilename = filename;
+}
+
