@@ -1,5 +1,5 @@
 /******************************************************************************
- * Copyright (C) 2011 Patrick Wacker
+ * Copyright (C) 2011-2013 Patrick Wacker
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the Free
  * Software Foundation; either version 2 of the License, or (at your option)
@@ -16,10 +16,10 @@
  ******************************************************************************
  * Dont forget: svn propset svn:keywords "Date Author Rev HeadURL" filename
  ******************************************************************************
- * $HeadURL: http://schmufu.dyndns.org/svn/ab_transfers/tags/0.0.4.1/src/abt_settings.h $
+ * $HeadURL: http://schmufu.dyndns.org/svn/ab_transfers/tags/0.0.5.0/src/abt_settings.h $
  * $Author: Patrick Wacker $
- * $Date: 2012-09-10 17:26:45 +0200 (Mon, 10 Sep 2012) $
- * $Rev: 357 $
+ * $Date: 2013-09-05 14:15:09 +0200 (Thu, 05 Sep 2013) $
+ * $Rev: 587 $
  *
  * description:
  *
@@ -52,6 +52,7 @@ private:
 	QString m_recipientsFilename;
 	QString m_accountdataFilename;
 	QString m_historyFilename;
+	QString m_autoExportFilename;
 	QSettings *settings;
 	QList<abt_EmpfaengerInfo*>* m_recipientsList;
 	QHash<int, QString> *m_textKeyDescr;
@@ -68,11 +69,13 @@ public:
 	const QString getAccountDataFilename() const { return this->m_accountdataFilename; }
 	const QString getHistoryFilename() const { return this->m_historyFilename; }
 	const QString getDataDir() const { return this->m_dataDir; }
+	const QString autoExportFilename() const { return this->m_autoExportFilename; }
 
 	void setRecipientsFilename(const QString &filename);
 	void setAccountDataFilename(const QString &filename);
 	void setHistoryFilename(const QString &filename);
 	void setDataDir(const QString &dirname);
+	void setAutoExportFilename(const QString &filename);
 
 	const QList<abt_EmpfaengerInfo*>* loadKnownEmpfaenger();
 	void saveKnownEmpfaenger();
@@ -97,6 +100,15 @@ public:
 	bool autoAddNewRecipients() const;
 	void setAutoAddNewRecipients(bool value);
 
+	bool autoExportEnabled() const;
+	void setAutoExportEnabled(bool value);
+	const QString autoExportProfileName() const;
+	void setAutoExportProfileName(const QString name) const;
+	const QString autoExportPluginName() const;
+	void setAutoExportPluginName(const QString name) const;
+	bool autoExportAsTransaction() const;
+	void setAutoExportAsTransaction(bool value);
+
 	QStringList getAllProfileFavorites() const;
 	bool isProfileFavorit(const QString &name) const;
 	void setProfileFavorit(const QString &name, bool favorit);
@@ -106,6 +118,8 @@ public:
 	void setAdvancedOption(const QString &option, bool value);
 	void deleteAdvancedOption(const QString &option);
 
+	QString language() const;
+
 	void saveColWidth(const QString &name, int col, int width);
 	int getColWidth(const QString &name, int col, int def = 100);
 
@@ -121,6 +135,8 @@ public slots:
 	void onReplaceKnownRecipient(int position, abt_EmpfaengerInfo *newRecipient);
 	void addKnownRecipient(abt_EmpfaengerInfo* recipientInfo);
 	void deleteKnownRecipient(abt_EmpfaengerInfo* recipientInfo);
+
+	void setLanguage(const QString &language);
 };
 
 #endif // TRANS_SETTINGS_H
