@@ -1,5 +1,5 @@
 /******************************************************************************
- * Copyright (C) 2012 Patrick Wacker
+ * Copyright (C) 2012-2013 Patrick Wacker
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the Free
  * Software Foundation; either version 2 of the License, or (at your option)
@@ -16,10 +16,10 @@
  ******************************************************************************
  * Dont forget: svn propset svn:keywords "Date Author Rev HeadURL" filename
  ******************************************************************************
- * $HeadURL: http://schmufu.dyndns.org/svn/ab_transfers/tags/0.0.4.1/src/dialogs/dialogsettings.cpp $
+ * $HeadURL: http://schmufu.dyndns.org/svn/ab_transfers/tags/0.0.5.0/src/dialogs/dialogsettings.cpp $
  * $Author: Patrick Wacker $
- * $Date: 2013-05-20 16:30:59 +0200 (Mon, 20 May 2013) $
- * $Rev: 415 $
+ * $Date: 2013-09-05 15:50:04 +0200 (Thu, 05 Sep 2013) $
+ * $Rev: 590 $
  *
  * description:
  *	Dialog um die Einstellungen von AB-Transfers zu ändern.
@@ -54,6 +54,10 @@ DialogSettings::DialogSettings(abt_settings *settings, AB_BANKING *ab, QWidget *
 	this->imexp = new aqb_imexporters(ab); //loads all im-/exporters from aqbanking
 	this->imex_favorites = new QHash<QString, bool>();
 
+	QFont font(this->ui->label_11->font());
+	font.setPointSize(font.pointSize() - 1);
+	this->ui->label_11->setFont(font);
+
 	//normaly we want the first tab active after start (everybody could use
 	// the following public function to set the active tab after creation)
 	this->setActiveTab(0);
@@ -135,6 +139,7 @@ void DialogSettings::loadFromSettings()
 	this->ui->checkBox_jobAddedToOutput->setChecked(this->settings->showDialog("JobAddOutput"));
 	this->ui->checkBox_warnDeleteProfile->setChecked(this->settings->showDialog("ProfileConfirmDelete"));
 	this->ui->checkBox_warnDeleteHistory->setChecked(this->settings->showDialog("HistoryConfirmDelete"));
+	this->ui->checkBox_runtimeLanguageChange->setChecked(this->settings->showDialog("RuntimeLanguageChange"));
 
 	this->ui->checkBox_getBalance->setChecked(this->settings->appendJobToOutbox("getBalance"));
 	this->ui->checkBox_getStandingOrders->setChecked(this->settings->appendJobToOutbox("getStandingOrders"));
@@ -144,11 +149,36 @@ void DialogSettings::loadFromSettings()
 	this->ui->checkBox_adv_manualOutboxRearrange->setChecked(
 			this->settings->isAdvancedOptionSet("ManualOutboxRearrange"));
 
-	this->ui->checkBox_autoAddNewRecipients->setChecked(this->settings->autoAddNewRecipients());
-
 	this->loadFavoriteImExpFromSettings();
 
 	this->refreshImExPluginListWidget();
+	this->refreshAutoExportComboBoxPlugin();
+
+	this->ui->checkBox_autoAddNewRecipients->setChecked(this->settings->autoAddNewRecipients());
+	this->ui->checkBox_autoExport->setChecked(this->settings->autoExportEnabled());
+	this->ui->checkBox_autoExportAsTransaction->setChecked(this->settings->autoExportAsTransaction());
+	this->ui->lineEdit_autoExportFilename->setText(this->settings->autoExportFilename());
+
+	//update enable/disabled state of corresponding widgets
+	this->on_checkBox_autoExport_toggled(this->ui->checkBox_autoExport->isChecked());
+
+	//select previous selected plugin and profile entries
+	QString iexpName = this->settings->autoExportPluginName();
+	for (int i=0; i<this->ui->comboBox_plugin->count(); ++i) {
+		if (this->ui->comboBox_plugin->itemText(i) == iexpName) {
+			this->ui->comboBox_plugin->setCurrentIndex(i);
+			break;
+		}
+	}
+
+	iexpName = this->settings->autoExportProfileName();
+	for (int i=0; i<this->ui->comboBox_profile->count(); ++i) {
+		if (this->ui->comboBox_profile->itemText(i) == iexpName) {
+			this->ui->comboBox_profile->setCurrentIndex(i);
+			break;
+		}
+	}
+
 }
 
 //private
@@ -163,6 +193,7 @@ void DialogSettings::saveToSettings()
 	this->settings->setShowDialog("JobAddOutput", this->ui->checkBox_jobAddedToOutput->isChecked());
 	this->settings->setShowDialog("ProfileConfirmDelete", this->ui->checkBox_warnDeleteProfile->isChecked());
 	this->settings->setShowDialog("HistoryConfirmDelete", this->ui->checkBox_warnDeleteHistory->isChecked());
+	this->settings->setShowDialog("RuntimeLanguageChange", this->ui->checkBox_runtimeLanguageChange->isChecked());
 
 	this->settings->setAppendJobToOutbox("getBalance", this->ui->checkBox_getBalance->isChecked());
 	this->settings->setAppendJobToOutbox("getStandingOrders", this->ui->checkBox_getStandingOrders->isChecked());
@@ -174,6 +205,12 @@ void DialogSettings::saveToSettings()
 
 	this->settings->setAutoAddNewRecipients(this->ui->checkBox_autoAddNewRecipients->isChecked());
 
+	this->settings->setAutoExportEnabled(this->ui->checkBox_autoExport->isChecked());
+	this->settings->setAutoExportAsTransaction(this->ui->checkBox_autoExportAsTransaction->isChecked());
+	this->settings->setAutoExportPluginName(this->ui->comboBox_plugin->currentText());
+	this->settings->setAutoExportProfileName(this->ui->comboBox_profile->currentText());
+	this->settings->setAutoExportFilename(this->ui->lineEdit_autoExportFilename->text());
+
 	this->saveFavoriteImExpToSettings();
 
 }
@@ -366,6 +403,49 @@ void DialogSettings::refreshImExProfileTableWidget()
 
 }
 
+//private
+/** \brief updates the entries in the combo box for automatic export
+ *
+ * This function must only be called when the imexp (Im-/Export) object
+ * has loaded all plugins and profiles (this is the case when the slot
+ * updatedImExporters() was called or the object was just created).
+ */
+void DialogSettings::refreshAutoExportComboBoxPlugin()
+{
+	Q_ASSERT(this->imexp);
+	const QString currText = this->ui->comboBox_plugin->currentText();
+	int exportsAvailable;
+	int idx = 0;
+
+	this->ui->comboBox_plugin->clear();
+	foreach(const aqb_iePlugin *plugin, *this->imexp->getPlugins()) {
+		exportsAvailable = false;
+		foreach(aqb_ieProfile *profile, *plugin->getProfiles()) {
+			//the plugin must contain a profile useable for export
+			if (profile->getNames()->contains("export") &&
+			    profile->getValue("export").toInt() == 1) {
+				exportsAvailable = true;
+				break;
+			}
+		}
+
+		if (exportsAvailable) {
+			const QString pluginName = plugin->getName();
+			const QString pluginHint = plugin->getDescShort();
+			this->ui->comboBox_plugin->addItem(pluginName);
+			this->ui->comboBox_plugin->setItemData(this->ui->comboBox_plugin->count()-1,
+							       pluginHint,
+							       Qt::ToolTipRole);
+			if (currText == pluginName) {
+				idx = this->ui->comboBox_plugin->count() - 1;
+			}
+		}
+	}
+
+	//restore previous selected entry
+	this->ui->comboBox_plugin->setCurrentIndex(idx);
+}
+
 //private
 bool DialogSettings::getSelectedPluginAndProfile(const aqb_iePlugin **plugin,
 						 const aqb_ieProfile **profile) const
@@ -437,11 +517,14 @@ void DialogSettings::setActiveTab(int tabId)
 *
 * The refresh also changes the currentRow and emits the signal
 * currentRowChanged() which refreshes the tableWidget_profiles
+*
+* In addition the combo box entries for the automatic export are updated.
 */
 void DialogSettings::updatedImExporters()
 {
 	//we refresh the ListWidget for the plugins
 	this->refreshImExPluginListWidget();
+	this->refreshAutoExportComboBoxPlugin();
 }
 
 //private slot
@@ -529,6 +612,21 @@ void DialogSettings::on_toolButton_selectRecipients_clicked()
 	}
 }
 
+//private slot
+void DialogSettings::on_toolButton_selectAutoExportFilename_clicked()
+{
+	QString file = QFileDialog::getSaveFileName(this,
+						    tr("Automatischen Export Speichern in ..."),
+						    this->ui->lineEdit_dataDir->text(),
+						    tr("Alle Dateien (*.*)"),
+						    NULL);
+
+	if (!file.isEmpty() || QFile::exists(file)) {
+		this->ui->lineEdit_autoExportFilename->setText(file);
+	}
+}
+
+
 /**
  * @brief sets the states (enabled/disabled) of the refreshAtStart checkbox
  *
@@ -650,8 +748,8 @@ void DialogSettings::on_actionEditProfile_triggered()
 				 "Sie können dann also nur noch auf das geänderte "
 				 "Profil zugreifen und nicht mehr auf die "
 				 "ursprüngliche Version!<br />"
-				 "(<i>Nach dem löschen des lokalen Profils würde "
-				 "das globale wieder verwendet werden können)")
+				 "<i>Nach dem löschen des lokalen Profils würde "
+				 "das globale wieder verwendet werden können.</i>")
 			      .arg(profileName);
 
 		QMessageBox::information(this, tr("Globales Profil ändern"), msg);
@@ -706,7 +804,7 @@ void DialogSettings::on_actionEditProfile_triggered()
 					 "unerwarteter Fehler aufgetreten.<br />"
 					 "In den Debug-Ausgaben können evt. "
 					 "weitere nützliche Informationen "
-					 "enthalten sein").arg(profileName));
+					 "enthalten sein.").arg(profileName));
 	}
 
 	//im-/export profiles might be changed, reaload them
@@ -817,7 +915,7 @@ void DialogSettings::on_actionNewProfile_triggered()
 					 "unerwarteter Fehler aufgetreten.<br />"
 					 "In den Debug-Ausgaben können evt. "
 					 "weitere nützliche Informationen "
-					 "enthalten sein").arg(newname));
+					 "enthalten sein.").arg(newname));
 	}
 
 	//profile were saved, free the DB_NODE
@@ -906,3 +1004,80 @@ void DialogSettings::on_actionDeleteProfile_triggered()
 	this->reloadImExporters();
 
 }
+
+//private slot
+/** \brief reloads the profiles for the corresponding plugin.
+ *
+ * When the plugin selection changed, this function refresh the combobox
+ * for the profiles of the newly selected plugin.
+ */
+void DialogSettings::on_comboBox_plugin_currentIndexChanged(const QString &arg1)
+{
+	Q_ASSERT(this->imexp);
+	int idx = -1;
+	const QString currText = this->ui->comboBox_profile->currentText();
+	const QList<aqb_ieProfile*> *profiles = NULL;
+
+	if (this->imexp->getPluginByName(arg1) != NULL) {
+		profiles = this->imexp->getPluginByName(arg1)->getProfiles();
+	} else {
+		//no profiles available
+		this->ui->comboBox_profile->clear();
+		return;
+	}
+
+	this->ui->comboBox_profile->clear();
+	foreach(aqb_ieProfile *profile, *profiles) {
+		//export possible?
+		if (profile->getValue("export").isValid() &&
+		    profile->getValue("export").toBool()) {
+			const QString itemName = profile->getValue("name").toString();
+			const QString itemHint = profile->getValue("shortDescr").toString();
+
+			this->ui->comboBox_profile->addItem(itemName);
+			this->ui->comboBox_profile->setItemData(this->ui->comboBox_profile->count()-1,
+								itemHint, Qt::ToolTipRole);
+			if (currText == itemName) {
+				idx = this->ui->comboBox_profile->count() - 1;
+			}
+		}
+	}
+
+	//restore selected entry, set it to "default" (if possible) or set it
+	//to the first entry
+CURRENT_INDEX_CHANGED_SET_INDEX:
+	if (idx != -1) {
+		//idx is possible, use it
+		this->ui->comboBox_profile->setCurrentIndex(idx);
+		return;
+	} else {
+		for (int i=0; i<this->ui->comboBox_profile->count(); ++i) {
+			if (this->ui->comboBox_profile->itemText(i) == "default") {
+				idx = i;
+				//default idx found, use it
+				goto CURRENT_INDEX_CHANGED_SET_INDEX;
+			}
+		}
+	}
+
+	//set first entry, no used and no default entry was found
+	if (this->ui->comboBox_profile->count() >= 1) {
+		this->ui->comboBox_profile->setCurrentIndex(0);
+	}
+}
+
+//private slot
+/** \brief enables or disables corresponding widgets depending on \a checked state.
+ */
+void DialogSettings::on_checkBox_autoExport_toggled(bool checked)
+{
+	this->ui->lineEdit_autoExportFilename->setEnabled(checked);
+	this->ui->checkBox_autoExportAsTransaction->setEnabled(checked);
+	this->ui->comboBox_plugin->setEnabled(checked);
+	this->ui->comboBox_profile->setEnabled(checked);
+	this->ui->toolButton_selectAutoExportFilename->setEnabled(checked);
+	this->ui->label_8->setEnabled(checked);
+	this->ui->label_9->setEnabled(checked);
+	this->ui->label_10->setEnabled(checked);
+	this->ui->label_11->setEnabled(checked);
+}
