@@ -16,10 +16,10 @@
  ******************************************************************************
  * Dont forget: svn propset svn:keywords "Date Author Rev HeadURL" filename
  ******************************************************************************
- * $HeadURL: http://schmufu.dyndns.org/svn/ab_transfers/tags/0.0.4.1/src/main.cpp $
+ * $HeadURL: http://schmufu.dyndns.org/svn/ab_transfers/tags/0.0.5.0/src/main.cpp $
  * $Author: Patrick Wacker $
- * $Date: 2013-05-16 20:11:36 +0200 (Thu, 16 May 2013) $
- * $Rev: 398 $
+ * $Date: 2013-09-07 15:37:47 +0200 (Sat, 07 Sep 2013) $
+ * $Rev: 594 $
  *
  * description:
  *
@@ -54,8 +54,14 @@ int main(int argc, char *argv[])
 	int apprv;
 	QApplication app(argc, argv);
 
+#if (QT_VERSION >= QT_VERSION_CHECK(5, 0, 0))
+#warning "compiling with Qt version >= 5.0.0. This is not tested well!"
+#else
+	//setCodecForTr() and setCodedForCString() are removed in Qt 5.0.0
+	//see http://qt-project.org/doc/qt-5.0/qtdoc/sourcebreaks.html
 	QTextCodec::setCodecForTr(QTextCodec::codecForName("UTF-8"));
 	QTextCodec::setCodecForCStrings(QTextCodec::codecForName("UTF-8"));
+#endif
 	QTextCodec::setCodecForLocale(QTextCodec::codecForName("UTF-8"));
 	QLocale::setDefault(QLocale(QLocale::German, QLocale::Germany));
 
@@ -65,32 +71,6 @@ int main(int argc, char *argv[])
 	qInstallMsgHandler(myMessageHandler);
 
 
-	/* At the moment, AB-Transfers is only available in German.
-	 * We set the language for the qt library to german, so that the
-	 * Qt text messages are also in german.
-	 */
-
-	qDebug() << "current system locale name:"
-		 << QLocale::system().name();
-	qDebug() << "search path for qt library translations:"
-		 << QLibraryInfo::location(QLibraryInfo::TranslationsPath);
-
-	QTranslator qtTranslator;
-	qDebug() << "setting default language for qt to: qt_de_DE "
-		 << "(regardless of the current system language)";
-	qtTranslator.load("qt_de_DE",
-			  QLibraryInfo::location(QLibraryInfo::TranslationsPath));
-	app.installTranslator(&qtTranslator);
-
-	/* The following could be enabled when translations for the program
-	 * are done. The search path for the application specific translation
-	 * must be adjusted!
-	 */
-//	QTranslator myappTranslator;
-//	myappTranslator.load("abtransfers_" + QLocale::system().name());
-//	app.installTranslator(&myappTranslator);
-
-
 	#ifdef ABTRANSFER_VERSION
 		app.setApplicationVersion(ABTRANSFER_VERSION);
 	#else
@@ -163,12 +143,6 @@ int main(int argc, char *argv[])
 
 	MainWindow *w = new MainWindow();
 
-	qDebug("RESTORING LAST STATE");
-	QByteArray ba = settings->loadWindowGeometry();
-	if (!ba.isEmpty()) w->restoreGeometry(ba);
-	ba = settings->loadWindowState();
-	if (!ba.isEmpty()) w->restoreState(ba, 1);
-
 	qDebug("BEFORE SHOW");
 	w->show();
 	qDebug("AFTER SHOW");
