@@ -16,10 +16,10 @@
  ******************************************************************************
  * Dont forget: svn propset svn:keywords "Date Author Rev HeadURL" filename
  ******************************************************************************
- * $HeadURL: http://schmufu.dyndns.org/svn/ab_transfers/tags/0.0.4.1/src/mainwindow.h $
+ * $HeadURL: http://schmufu.dyndns.org/svn/ab_transfers/tags/0.0.5.0/src/mainwindow.h $
  * $Author: Patrick Wacker $
- * $Date: 2013-05-12 21:03:55 +0200 (Sun, 12 May 2013) $
- * $Rev: 391 $
+ * $Date: 2013-08-26 11:16:58 +0200 (Mon, 26 Aug 2013) $
+ * $Rev: 581 $
  *
  * description:
  *
@@ -49,6 +49,7 @@
 
 class widgetTransfer;
 class widgetRecurrence;
+class TranslationChooser;
 
 namespace Ui {
 	class MainWindow;
@@ -70,6 +71,8 @@ protected:
 	void changeEvent(QEvent *e);
 	void closeEvent(QCloseEvent *e);
 
+	void retranslateCppCode();
+
 private:
 	Ui::MainWindow *ui;
 	aqb_Accounts *accounts;
@@ -109,8 +112,12 @@ private:
 
 	QTimer *timer;
 
+	TranslationChooser *translations;
+
 	void createActions();
+	void deleteActions();
 	void createMenus();
+	void deleteMenus();
 	void createDockToolbar();
 	void createWidgetsInScrollArea();
 	void createDockBankAccountWidget();
@@ -216,6 +223,8 @@ private slots:
 
 	void deleteHistoryItems(QList<abt_jobInfo*> jiList);
 
+	void checkTranslationVersion();
+
 };
 
 #endif // MAINWINDOW_H
