@@ -1,5 +1,5 @@
 /******************************************************************************
- * Copyright (C) 2012 Patrick Wacker
+ * Copyright (C) 2012-2013 Patrick Wacker
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the Free
  * Software Foundation; either version 2 of the License, or (at your option)
@@ -16,10 +16,10 @@
  ******************************************************************************
  * Dont forget: svn propset svn:keywords "Date Author Rev HeadURL" filename
  ******************************************************************************
- * $HeadURL: http://schmufu.dyndns.org/svn/ab_transfers/tags/0.0.4.1/src/pages/page_history.cpp $
+ * $HeadURL: http://schmufu.dyndns.org/svn/ab_transfers/tags/0.0.5.0/src/pages/page_history.cpp $
  * $Author: Patrick Wacker $
- * $Date: 2013-05-20 16:30:59 +0200 (Mon, 20 May 2013) $
- * $Rev: 415 $
+ * $Date: 2013-08-11 20:28:04 +0200 (Sun, 11 Aug 2013) $
+ * $Rev: 575 $
  *
  * description:
  *
@@ -71,9 +71,6 @@ page_history::page_history(const abt_history *history, QWidget *parent) :
 	//default sorting by 'executed at' in descending order
 	this->ui->treeWidget->sortByColumn(4, Qt::DescendingOrder);
 
-	//calling the itemSelectionChanged() slot enables/disables the actions
-	this->on_treeWidget_itemSelectionChanged();
-
 	connect(this->history, SIGNAL(historyListChanged(const abt_history*)),
 		this, SLOT(refreshTreeWidget(const abt_history*)));
 
@@ -100,6 +97,7 @@ void page_history::changeEvent(QEvent *e)
 	switch(e->type()) {
 	case QEvent::LanguageChange:
 		ui->retranslateUi(this);
+		this->retranslateCppCode();
 		break;
 	default:
 		break;
@@ -112,6 +110,20 @@ void page_history::resizeEvent(QResizeEvent *event)
 	QFrame::resizeEvent(event);
 }
 
+//protected
+/** \copydoc MainWindow::retranslateCppCode() */
+void page_history::retranslateCppCode()
+{
+	//we simply delete the actions and recreate them
+	delete this->actDeleteSelected;
+	delete this->actExportSelected;
+	delete this->actGenerateNewTransaction;
+	this->createActions();
+
+	//recreate all items in the treeWidget
+	this->refreshTreeWidget(this->history);
+}
+
 //private
 void page_history::setTreeWidgetColWidths()
 {
@@ -176,6 +188,9 @@ void page_history::createActions()
 		this, SLOT(onActDeleteSelected()));
 	this->ui->toolButton_delete->setDefaultAction(this->actDeleteSelected);
 	this->ui->treeWidget->addAction(this->actDeleteSelected);
+
+	//set the correct en-/disabled states on the actions
+	this->on_treeWidget_itemSelectionChanged();
 }
 
 /**
@@ -265,7 +280,7 @@ void page_history::onActDeleteSelected()
 	QString msgTitle = tr("Historie Eintrag löschen");
 	QString msgText = tr("Sollen die gewählten Einträge aus der Historie wirklich "
 			     "gelöscht werden?<br />"
-			     "<i>(Dies kann nicht rückgängig gemacht werden)</i>");
+			     "<i>Dies kann nicht rückgängig gemacht werden.</i>");
 	abt_dialog dialog(this, msgTitle, msgText,
 			  QDialogButtonBox::Yes | QDialogButtonBox::No,
 			  QDialogButtonBox::Yes, QMessageBox::Question,
@@ -367,9 +382,13 @@ QMenu *page_history::createExportContextMenu(QWidget *parent, const aqb_imexport
 }
 
 
-/**
- * @brief creates the export-context menu and exports the data according to
+/** \brief creates the export-context menu and exports the data according to
  *	  the user selection
+ *
+ * creates a ctx from the selected items in the history and saves this
+ * data with the selected profile from the plugin.
+ *
+ * Saving is done by a function from AqBanking.
  */
 //private slot
 void page_history::onActExportSelected()
@@ -385,13 +404,26 @@ void page_history::onActExportSelected()
 	QString dialogTitle = "";
 	QString tmpstr = "";
 
-	aqb_imexporters* iep = new aqb_imexporters(banking->getAqBanking());
-
+	aqb_imexporters *iep = new aqb_imexporters(banking->getAqBanking());
 	QMenu *exportConextMenu = this->createExportContextMenu(this, iep);
-
-
 	QAction *sel = exportConextMenu->exec(QCursor::pos());
 
+	//create a ctx for export from all selected items. This must be called
+	//before "QFileDialog::getSaveFileName()", otherwise the item selections
+	//are removed and NULL is returned from "getContextFromSelected()"
+	ctx = this->getContextFromSelected();
+
+	if (!ctx) {
+		QMessageBox::warning(this, tr("Export fehlgeschlagen"),
+				     tr("Es wurden keine zu exportierende Daten "
+					"ausgewählt.<br /><br />"
+					"<i>Dies sollte nicht auftreten! Wenn "
+					"diese Meldung reproduzierbar ist, melden "
+					"Sie es bitte als Bug.</i>"),
+				     QMessageBox::Ok);
+		goto ONACTEXPORTSELECTED_CLEANUP;
+	}
+
 	if (!sel) {
 		//no context menu item selected, abort
 		goto ONACTEXPORTSELECTED_CLEANUP;
@@ -405,7 +437,6 @@ void page_history::onActExportSelected()
 		goto ONACTEXPORTSELECTED_CLEANUP;
 	}
 
-
 	//we stored the pointer to plugin and profile in the user-data of the
 	//action, lets restore them
 	plugin = reinterpret_cast<aqb_iePlugin*>(sel->userData(0));
@@ -436,24 +467,18 @@ void page_history::onActExportSelected()
 		goto ONACTEXPORTSELECTED_CLEANUP;
 	}
 
-	//create a ctx from the selected items in the history and save this
-	//data with the selected profile from the plugin.
-	//Saving is done by a function from AqBanking.
-
-	//create a context for export from all selected items
-	ctx = this->getContextFromSelected();
-
-	err = AB_Banking_ExportToFile(banking->getAqBanking(),
-				      ctx, plugin->getName(),
-				      profile->getValue("name").toString().toUtf8(),
-				      saveFilename.toUtf8());
-
-	//we must free the ctx after using it
-	AB_ImExporterContext_free(ctx);
+	if (ctx) {
+		err = AB_Banking_ExportToFile(banking->getAqBanking(),
+					      ctx, plugin->getName(),
+					      profile->getValue("name").toString().toUtf8(),
+					      saveFilename.toUtf8());
+	} else {
+		err = 99; //no ctx available!
+	}
 
 	if (err != 0) {
 		QMessageBox::critical(this, tr("Export fehlerhaft"),
-				      tr("Beim Export trat ein Fehler auf!</ br>"
+				      tr("Beim Export trat ein Fehler auf!<br />"
 					 "Bitte kontrollieren Sie die exportierten "
 					 "Daten und wiederholen ggf. den "
 					 "Vorgang!"),
@@ -468,7 +493,10 @@ void page_history::onActExportSelected()
 
 
 ONACTEXPORTSELECTED_CLEANUP:
-
+	if (ctx) {
+		//we must free the ctx after using it
+		AB_ImExporterContext_free(ctx);
+	}
 	delete exportConextMenu; //menu and all childs no longer needed
 	delete iep; //also deletes ALL childs objects from aqb_imexporters!
 }
@@ -486,6 +514,9 @@ ONACTEXPORTSELECTED_CLEANUP:
 //public slot
 void page_history::refreshTreeWidget(const abt_history *hist)
 {
+	//store the newly supplied history (could be changed, but shouldn't)
+	this->history = hist;
+
 	if ((hist == NULL) ||
 	    (hist->getHistoryList()->size() == 0)) {
 		this->ui->treeWidget->clear(); //delete all items
@@ -601,13 +632,17 @@ void page_history::on_treeWidget_itemClicked(QTreeWidgetItem *item, int /* colum
 }
 
 //private slot
-/**
-  * @brief saves the @a newSize of the @a column in the settings
+/** \brief saves the @a newSize of the @a column in the settings
   *
+  * The new width is only saved when the header is visible.
   */
 void page_history::onTreeWidgetColumnResized(int column, int /* oldSize */, int newSize)
 {
-	settings->saveColWidth("history", column, newSize);
+	if (!this->ui->treeWidget->isHeaderHidden()) {
+		//if no header is displayed there are no columns.
+		//Only save the width when headers are visible.
+		settings->saveColWidth("history", column, newSize);
+	}
 }
 
 //private slot
