@@ -16,10 +16,10 @@
  ******************************************************************************
  * Dont forget: svn propset svn:keywords "Date Author Rev HeadURL" filename
  ******************************************************************************
- * $HeadURL: http://schmufu.dyndns.org/svn/ab_transfers/tags/0.0.4.1/src/widgets/bankaccountswidget.h $
+ * $HeadURL: http://schmufu.dyndns.org/svn/ab_transfers/tags/0.0.5.0/src/widgets/bankaccountswidget.h $
  * $Author: Patrick Wacker $
- * $Date: 2012-07-12 20:51:34 +0200 (Thu, 12 Jul 2012) $
- * $Rev: 298 $
+ * $Date: 2013-08-11 20:28:04 +0200 (Sun, 11 Aug 2013) $
+ * $Rev: 575 $
  *
  * description:
  *
@@ -64,12 +64,13 @@ protected:
 	bool eventFilter(QObject *obj, QEvent *event);
 	void twMouseMoveEvent(QMouseEvent *event);
 	void twMousePressEvent(QMouseEvent *event);
-
+	void retranslateCppCode();
 
 private:
 	Ui::BankAccountsWidget *ui;
 
 	void setValuesForItem(QTreeWidgetItem *item, const aqb_AccountInfo *acc) const;
+	void setHeaderItemCaptions(QTreeWidgetItem *headerItem) const;
 
 signals:
 	void Account_Changed(const aqb_AccountInfo *new_account);
