@@ -16,10 +16,10 @@
  ******************************************************************************
  * Dont forget: svn propset svn:keywords "Date Author Rev HeadURL" filename
  ******************************************************************************
- * $HeadURL: http://schmufu.dyndns.org/svn/ab_transfers/tags/0.0.4.1/src/widgets/widgetknowndatedtransfers.h $
+ * $HeadURL: http://schmufu.dyndns.org/svn/ab_transfers/tags/0.0.5.0/src/widgets/widgetknowndatedtransfers.h $
  * $Author: Patrick Wacker $
- * $Date: 2012-07-12 20:51:34 +0200 (Thu, 12 Jul 2012) $
- * $Rev: 298 $
+ * $Date: 2013-08-11 20:28:04 +0200 (Sun, 11 Aug 2013) $
+ * $Rev: 575 $
  *
  * description:
  *
@@ -48,6 +48,10 @@ class widgetKnownDatedTransfers : public QWidget
 public:
 	explicit widgetKnownDatedTransfers(QWidget *parent = 0);
 
+protected:
+	void changeEvent(QEvent *e);
+	void retranslateCppCode();
+
 private:
 	QTreeWidget *treeWidget;
 	QAction *actEdit;
