@@ -16,10 +16,10 @@
  ******************************************************************************
  * Dont forget: svn propset svn:keywords "Date Author Rev HeadURL" filename
  ******************************************************************************
- * $HeadURL: http://schmufu.dyndns.org/svn/ab_transfers/tags/0.0.4.1/src/widgets/widgetknownstandingorders.h $
+ * $HeadURL: http://schmufu.dyndns.org/svn/ab_transfers/tags/0.0.5.0/src/widgets/widgetknownstandingorders.h $
  * $Author: Patrick Wacker $
- * $Date: 2013-05-13 22:55:56 +0200 (Mon, 13 May 2013) $
- * $Rev: 395 $
+ * $Date: 2013-08-11 20:28:04 +0200 (Sun, 11 Aug 2013) $
+ * $Rev: 575 $
  *
  * description:
  *	This widget is used to display all known standing orders for one
@@ -57,6 +57,10 @@ class widgetKnownStandingOrders : public QWidget
 public:
 	explicit widgetKnownStandingOrders(QWidget *parent = 0);
 
+protected:
+	void changeEvent(QEvent *e);
+	void retranslateCppCode();
+
 private:
 	QTreeWidget *treeWidget; //!< main widget for display
 	QAction *actEdit; //!< QAction handling edit
