@@ -16,10 +16,10 @@
  ******************************************************************************
  * Dont forget: svn propset svn:keywords "Date Author Rev HeadURL" filename
  ******************************************************************************
- * $HeadURL: http://schmufu.dyndns.org/svn/ab_transfers/tags/0.0.4.1/src/widgets/widgettransfer.cpp $
+ * $HeadURL: http://schmufu.dyndns.org/svn/ab_transfers/tags/0.0.5.0/src/widgets/widgettransfer.cpp $
  * $Author: Patrick Wacker $
- * $Date: 2013-05-20 16:30:59 +0200 (Mon, 20 May 2013) $
- * $Rev: 415 $
+ * $Date: 2013-08-11 20:28:04 +0200 (Sun, 11 Aug 2013) $
+ * $Rev: 575 $
  *
  * description:
  *
@@ -74,15 +74,15 @@ widgetTransfer::widgetTransfer(AB_JOB_TYPE type,
 	case AB_Job_TypeEuTransfer :
 	case AB_Job_TypeDebitNote :
 	case AB_Job_TypeSepaDebitNote : {
-		this->setWindowTitle(tr("nicht Implementiert"));
+		this->setWindowTitle(tr("Nicht implementiert"));
 		QLabel *notImplementet = new QLabel(tr(
 				"<h3><font color=red>"
 				"Der \"Job\" '%1' ist leider noch nicht "
 				"implementiert.<br />"
 				"Bitte haben Sie noch etwas Geduld und warten "
 				"auf eine Aktualisierung.</font></h3>"
-				"(Eventuell folgende Texte sind ablaufbedingt "
-				"und können ignoriert werden)"
+				"<i>Eventuell folgende Texte sind ablaufbedingt "
+				"und können ignoriert werden.</i>"
 				).arg(abt_conv::JobTypeToQString(this->m_type)));
 		notImplementet->setWordWrap(true);
 		notImplementet->setAlignment(Qt::AlignTop | Qt::AlignLeft);
@@ -219,15 +219,19 @@ void widgetTransfer::my_createNotAvailableJobText()
 		BankName = tr("unbekannt");
 		KontoName = tr("unbekannt");
 	} else {
-		BankName = this->m_accountAtCreation->BankName();
-		KontoName = this->m_accountAtCreation->Name();
+		BankName = QString("%1 [%2]").arg(
+				   this->m_accountAtCreation->BankName(),
+				   this->m_accountAtCreation->BankCode());
+		KontoName = QString("%1 [%2]").arg(
+				    this->m_accountAtCreation->Name(),
+				    this->m_accountAtCreation->Number());
 	}
 	QLabel *description = new QLabel(tr(
 			"AB-Transfers unterstützt zwar die Verwendung von '%1', "
-			"aber über die 'BankParameterDaten' (BPD) wurde von dem "
+			"aber über die 'UserParameterDaten' (UPD) wurde von dem "
 			"Institut (%2) mitgeteilt das dieser Auftrag bei dem "
 			"gewählten Konto (%3) nicht unterstützt wird.<br />"
-			"Die BPD werden von Zeit zu Zeit aktualisert. Eventuell "
+			"Die UPD werden von Zeit zu Zeit aktualisert. Eventuell "
 			"wird zu einem späteren Zeitpunkt der Auftrag vom "
 			"Institut unterstützt werden. Dies ist aber abhängig "
 			"vom Institut und kann von AB-Transfers nicht "
@@ -339,7 +343,7 @@ void widgetTransfer::my_create_dated_transfer_form(bool newTransfer)
 	this->my_create_local_remote_horizontal(newTransfer);
 	this->my_create_value_with_label_left();
 	this->my_create_purpose();
-	this->datedDate = new widgetDate(tr("Ausführen am"), Qt::AlignLeft, this);
+	this->datedDate = new widgetDate(tr("Ausführen am"), Qt::AlignLeft);
 	this->my_create_textKey();
 
 	this->layoutMain->addLayout(this->layoutAccount);
@@ -378,7 +382,7 @@ void widgetTransfer::my_create_localAccount_groupbox(bool /* newTransfer */,
 {
 	this->groupBoxLocal = new QGroupBox(tr("Absender"));
 	QVBoxLayout *gbll = new QVBoxLayout();
-	this->localAccount = new widgetAccountData(this,
+	this->localAccount = new widgetAccountData(NULL,
 						   this->m_accountAtCreation,
 						   this->m_allAccounts);
 	gbll->addWidget(this->localAccount);
@@ -400,7 +404,7 @@ void widgetTransfer::my_create_remoteAccount_groupbox(bool /* newTransfer */,
 		//account input as for the local-account input.
 		this->groupBoxRemote = new QGroupBox(tr("Empfänger"));
 		QVBoxLayout *gbrl = new QVBoxLayout();
-		this->remoteAccount = new widgetAccountData(this,
+		this->remoteAccount = new widgetAccountData(NULL,
 							    this->m_accountAtCreation,
 							    this->m_allAccounts);
 		gbrl->addWidget(this->remoteAccount);
@@ -409,7 +413,7 @@ void widgetTransfer::my_create_remoteAccount_groupbox(bool /* newTransfer */,
 		//Die RemoteKontoEingabe ermöglichen
 		this->groupBoxRemote = new QGroupBox(tr("Empfänger"));
 		QVBoxLayout *gbrl = new QVBoxLayout();
-		this->remoteAccount = new widgetAccountData(this, NULL, NULL, sepaFields);
+		this->remoteAccount = new widgetAccountData(NULL, NULL, NULL, sepaFields);
 		this->remoteAccount->setAllowDropAccount(allowLocal);
 		this->remoteAccount->setAllowDropKnownRecipient(allowKnownRecipient);
 		gbrl->addWidget(this->remoteAccount);
@@ -430,7 +434,7 @@ void widgetTransfer::my_create_remoteAccount_groupbox(bool /* newTransfer */,
 void widgetTransfer::my_create_value_with_label_left()
 {
 	QLabel *labelValue = new QLabel(tr("Betrag (Euro,Cent):"));
-	this->value = new widgetValue(this);
+	this->value = new widgetValue();
 	this->layoutValue = new QHBoxLayout();
 	this->layoutValue->addWidget(labelValue, 2, Qt::AlignRight);
 	this->layoutValue->addWidget(this->value, 0, Qt::AlignRight);
@@ -440,7 +444,7 @@ void widgetTransfer::my_create_value_with_label_left()
 void widgetTransfer::my_create_value_with_label_top()
 {
 	QLabel *labelValue = new QLabel(tr("Betrag: (Euro,Cent)"));
-	this->value = new widgetValue(this);
+	this->value = new widgetValue();
 	this->layoutValue = new QVBoxLayout();
 	this->layoutValue->addWidget(labelValue, 2, Qt::AlignRight);
 	this->layoutValue->addWidget(this->value, 0, Qt::AlignRight);
@@ -449,9 +453,9 @@ void widgetTransfer::my_create_value_with_label_top()
 //private
 void widgetTransfer::my_create_purpose()
 {
-	this->purpose = new widgetPurpose(this);
+	this->purpose = new widgetPurpose();
 
-	QLabel *labelPurpose = new QLabel("Verwendungszweck");
+	QLabel *labelPurpose = new QLabel(tr("Verwendungszweck"));
 	this->layoutPurpose = new QVBoxLayout();
 	this->layoutPurpose->addWidget(labelPurpose);
 	this->layoutPurpose->addWidget(this->purpose);
@@ -467,7 +471,7 @@ void widgetTransfer::my_create_textKey()
 void widgetTransfer::my_create_recurrence()
 {
 	this->groubBoxRecurrence = new QGroupBox(tr("Ausführungsdaten"));
-	this->recurrence = new widgetRecurrence(this);
+	this->recurrence = new widgetRecurrence();
 
 	QVBoxLayout *grbl = new QVBoxLayout();
 	grbl->addWidget(this->recurrence);
@@ -564,7 +568,15 @@ void widgetTransfer::setAllLimits(const abt_transactionLimits *limits)
 		this->recurrence->setLimitAllowMonthly(limits->AllowMonthly);
 		this->recurrence->setLimitAllowWeekly(limits->AllowWeekly);
 		this->recurrence->setLimitAllowChangeFirstExecutionDate(limits->AllowChangeFirstExecutionDate);
-		this->recurrence->setLimitAllowChangeLastExecutionDate(limits->AllowChangeLastExecutionDate);
+
+		if (banking->isLastDateSupported()) {
+			this->recurrence->setLimitAllowChangeLastExecutionDate(limits->AllowChangeLastExecutionDate);
+		} else {
+			//last date is not supported by aqbanking
+			this->recurrence->setLimitAllowChangeLastExecutionDate(-1);
+			//"until further" is checked if the date is invalid
+			this->recurrence->setLastExecutionDay(QDate());
+		}
 	}
 
 	if (this->datedDate != NULL) {
