@@ -16,10 +16,10 @@
  ******************************************************************************
  * Dont forget: svn propset svn:keywords "Date Author Rev HeadURL" filename
  ******************************************************************************
- * $HeadURL: http://schmufu.dyndns.org/svn/ab_transfers/tags/0.0.4.1/src/widgets/widgetvalue.h $
+ * $HeadURL: http://schmufu.dyndns.org/svn/ab_transfers/tags/0.0.5.0/src/widgets/widgetvalue.h $
  * $Author: Patrick Wacker $
- * $Date: 2012-07-12 20:51:34 +0200 (Thu, 12 Jul 2012) $
- * $Rev: 298 $
+ * $Date: 2013-07-07 09:39:42 +0200 (Sun, 07 Jul 2013) $
+ * $Rev: 524 $
  *
  * description:
  *
@@ -36,6 +36,7 @@
 #include <QtCore/QDebug>
 
 #include "../abt_conv.h"
+#include "widgetcalculator.h"
 
 /** \brief Widget zur Anzeige und Eingabe eines Betrages
  *
@@ -48,10 +49,17 @@ public:
 	explicit widgetValue(QWidget *parent = 0);
 	~widgetValue();
 
+protected:
+	QWidget *focusWidget();
+	bool eventFilter(QObject *o, QEvent *e);
+
 private:
 	QLineEdit *value;
 	QLineEdit *currency;
+	WidgetCalculator *calculator;
+	QFrame *calcFrame;
 
+	void createCalcFrame();
 
 public:
 	QString getValue() const;
@@ -61,7 +69,12 @@ public:
 
 signals:
 
+private slots:
+	void calculatorResult();
+
 public slots:
+	void showCalculator();
+	void showCalculator(QKeyEvent *e);
 	void clearAll();
 	void setValue(const QString &value);
 	void setValue(const AB_VALUE *abv);
@@ -71,6 +84,7 @@ public slots:
 
 	void setLimitAllowChange(int b);
 
+
 };
 
 #endif // WIDGETVALUE_H
